pub struct Info {Show 15 fields
pub state: Option<State>,
pub ca_state: Option<CongestionControlState>,
pub rto_usec: Option<u32>,
pub tcpi_snd_mss: Option<u32>,
pub tcpi_rcv_mss: Option<u32>,
pub tcpi_last_data_sent_msec: Option<u32>,
pub tcpi_last_ack_recv_msec: Option<u32>,
pub rtt_usec: Option<u32>,
pub rtt_var_usec: Option<u32>,
pub snd_ssthresh: Option<u32>,
pub snd_cwnd: Option<u32>,
pub tcpi_total_retrans: Option<u32>,
pub tcpi_segs_out: Option<u64>,
pub tcpi_segs_in: Option<u64>,
pub reorder_seen: Option<bool>,
/* private fields */
}Expand description
TCP protocol state.
Fields
state: Option<State>The current state of the TCP state machine.
ca_state: Option<CongestionControlState>The current state of the TCP congention avoidance state machine.
rto_usec: Option<u32>The current RTO value in microseconds.
tcpi_snd_mss: Option<u32>The maximum segment size (MSS) this endpoint can send.
tcpi_rcv_mss: Option<u32>The maximum segment size (MSS) this endpoint can receive.
tcpi_last_data_sent_msec: Option<u32>Time since data was last sent on the connection in milliseconds.
tcpi_last_ack_recv_msec: Option<u32>Time since the most recent ACK was received in milliseconds.
rtt_usec: Option<u32>The estimated smoothed roundtrip time in microseconds.
rtt_var_usec: Option<u32>The smoothed mean deviation of the roundtrip time in microseconds.
snd_ssthresh: Option<u32>The sending slow start threshold in segments.
snd_cwnd: Option<u32>The current sending congestion window in segments.
tcpi_total_retrans: Option<u32>The total number of retransmission events.
tcpi_segs_out: Option<u64>The total number of segments transmitted.
tcpi_segs_in: Option<u64>The total number of segments received.
reorder_seen: Option<bool>Whether the connection thinks it has ever seen reordering.